@@ -1,47 +1,51 @@
 package List::AllUtils;
-$List::AllUtils::VERSION = '0.08';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.10';
+
 # List::Util does not define an :all tag
 BEGIN {
     use List::Util 1.31 ();
     List::Util->import(@List::Util::EXPORT_OK);
 
-    use List::MoreUtils 0.28;
+    use List::SomeUtils 0.50;
 
     my %imported = map { $_ => 1 } @List::Util::EXPORT_OK;
-    List::MoreUtils->import( grep { !$imported{$_} }
-            @List::MoreUtils::EXPORT_OK );
+    List::SomeUtils->import( grep { !$imported{$_} }
+            @List::SomeUtils::EXPORT_OK );
 }
 
 use base 'Exporter';
 
-our @EXPORT_OK = ( @List::Util::EXPORT_OK, @List::MoreUtils::EXPORT_OK );
+our @EXPORT_OK = ( @List::Util::EXPORT_OK, @List::SomeUtils::EXPORT_OK );
 
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 1;
 
-# ABSTRACT: Combines List::Util and List::MoreUtils in one bite-sized package
+# ABSTRACT: Combines List::Util and List::SomeUtils in one bite-sized package
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-List::AllUtils - Combines List::Util and List::MoreUtils in one bite-sized package
+List::AllUtils - Combines List::Util and List::SomeUtils in one bite-sized package
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
     use List::AllUtils qw( first any );
 
-    # _Everything_ from List::Util and List::MoreUtils
+    # _Everything_ from List::Util and List::SomeUtils
     use List::AllUtils qw( :all );
 
     my @numbers = ( 1, 2, 3, 5, 7 );
@@ -51,12 +55,20 @@ version 0.08
 =head1 DESCRIPTION
 
 Are you sick of trying to remember whether a particular helper is
-defined in C<List::Util> or C<List::MoreUtils>? I sure am. Now you
+defined in L<List::Util> or L<List::SomeUtils>? I sure am. Now you
 don't have to remember. This module will export all of the functions
 that either of those two modules defines.
 
 Note that all function documentation has been shamelessly copied from
-L<List::Util> and <List::MoreUtils>.
+L<List::Util> and L<List::SomeUtils>.
+
+=head2 Which One Wins?
+
+Recently, L<List::Util> has started including some of the subs that used to
+only be in L<List::SomeUtils>. This module always exports the version provided
+by L<List::Util>.
+
+The docs below come from L<List::Util> 1.31 and L<List::SomeUtils> 0.50.
 
 =head1 LIST-REDUCTION FUNCTIONS
 
@@ -279,275 +291,516 @@ Returns the elements of LIST in a random order
 
     @cards = shuffle 0..51      # 0..51 in a random order
 
-=head1 List::MoreUtils FUNCTIONS
+=head1 List::SomeUtils FUNCTIONS
 
-=head2 any BLOCK LIST
+=head2 Junctions
+
+=head3 I<Treatment of an empty list>
+
+There are two schools of thought for how to evaluate a junction on an
+empty list:
+
+=over
+
+=item * Reduction to an identity (boolean)
+
+=item * Result is undefined (three-valued)
+
+=back
+
+In the first case, the result of the junction applied to the empty list is
+determined by a mathematical reduction to an identity depending on whether
+the underlying comparison is "or" or "and". Conceptually:
+
+                    "any are true"      "all are true"
+                    --------------      --------------
+    2 elements:     A || B || 0         A && B && 1
+    1 element:      A || 0              A && 1
+    0 elements:     0                   1
+
+In the second case, three-value logic is desired, in which a junction applied
+to an empty list returns C<undef> rather than true or false.
+
+Junctions with a C<_u> suffix implement three-valued logic. Those
+without are boolean.
+
+=head3 all BLOCK LIST
+
+=head3 all_u BLOCK LIST
+
+Returns a true value if all items in LIST meet the criterion given through
+BLOCK. Sets C<$_> for each item in LIST in turn:
+
+  print "All values are non-negative"
+    if all { $_ >= 0 } ($x, $y, $z);
+
+For an empty LIST, C<all> returns true (i.e. no values failed the condition)
+and C<all_u> returns C<undef>.
+
+Thus, C<< all_u(@list) >> is equivalent to C<< @list ? all(@list) : undef >>.
+
+B<Note>: because Perl treats C<undef> as false, you must check the return value
+of C<all_u> with C<defined> or you will get the opposite result of what you
+expect.
+
+=head3 any BLOCK LIST
+
+=head3 any_u BLOCK LIST
 
 Returns a true value if any item in LIST meets the criterion given through
 BLOCK. Sets C<$_> for each item in LIST in turn:
 
-    print "At least one value undefined"
-        if any { ! defined($_) } @list;
+  print "At least one non-negative value"
+    if any { $_ >= 0 } ($x, $y, $z);
 
-Returns false otherwise, or if LIST is empty.
+For an empty LIST, C<any> returns false and C<any_u> returns C<undef>.
 
-=head2 all BLOCK LIST
+Thus, C<< any_u(@list) >> is equivalent to C<< @list ? any(@list) : undef >>.
 
-Returns a true value if all items in LIST meet the criterion given through
-BLOCK, or if LIST is empty. Sets C<$_> for each item in LIST in turn:
+=head3 none BLOCK LIST
 
-    print "All items defined"
-        if all { defined($_) } @list;
-
-Returns false otherwise.
-
-=head2 none BLOCK LIST
+=head3 none_u BLOCK LIST
 
 Logically the negation of C<any>. Returns a true value if no item in LIST meets
-the criterion given through BLOCK, or if LIST is empty. Sets C<$_> for each item
-in LIST in turn:
+the criterion given through BLOCK. Sets C<$_> for each item in LIST in turn:
 
-    print "No value defined"
-        if none { defined($_) } @list;
+  print "No non-negative values"
+    if none { $_ >= 0 } ($x, $y, $z);
 
-Returns false otherwise.
+For an empty LIST, C<none> returns true (i.e. no values failed the condition)
+and C<none_u> returns C<undef>.
 
-=head2 notall BLOCK LIST
+Thus, C<< none_u(@list) >> is equivalent to C<< @list ? none(@list) : undef >>.
+
+B<Note>: because Perl treats C<undef> as false, you must check the return value
+of C<none_u> with C<defined> or you will get the opposite result of what you
+expect.
+
+=head3 notall BLOCK LIST
+
+=head3 notall_u BLOCK LIST
 
 Logically the negation of C<all>. Returns a true value if not all items in LIST
 meet the criterion given through BLOCK. Sets C<$_> for each item in LIST in
 turn:
 
-    print "Not all values defined"
-        if notall { defined($_) } @list;
+  print "Not all values are non-negative"
+    if notall { $_ >= 0 } ($x, $y, $z);
 
-Returns false otherwise, or if LIST is empty.
+For an empty LIST, C<notall> returns false and C<notall_u> returns C<undef>.
 
-=head2 true BLOCK LIST
+Thus, C<< notall_u(@list) >> is equivalent to C<< @list ? notall(@list) : undef >>.
 
-Counts the number of elements in LIST for which the criterion in BLOCK is true.
-Sets C<$_> for  each item in LIST in turn:
+=head3 one BLOCK LIST
 
-    printf "%i item(s) are defined", true { defined($_) } @list;
+=head3 one_u BLOCK LIST
 
-=head2 false BLOCK LIST
+Returns a true value if precisely one item in LIST meets the criterion
+given through BLOCK. Sets C<$_> for each item in LIST in turn:
 
-Counts the number of elements in LIST for which the criterion in BLOCK is false.
-Sets C<$_> for each item in LIST in turn:
+    print "Precisely one value defined"
+        if one { defined($_) } @list;
 
-    printf "%i item(s) are not defined", false { defined($_) } @list;
+Returns false otherwise.
 
-=head2 firstidx BLOCK LIST
+For an empty LIST, C<one> returns false and C<one_u> returns C<undef>.
 
-=head2 first_index BLOCK LIST
+The expression C<one BLOCK LIST> is almost equivalent to
+C<1 == true BLOCK LIST>, except for short-cutting.
+Evaluation of BLOCK will immediately stop at the second true value.
 
-Returns the index of the first element in LIST for which the criterion in BLOCK
-is true. Sets C<$_> for each item in LIST in turn:
+=head2 Transformation
 
-    my @list = (1, 4, 3, 2, 4, 6);
-    printf "item with index %i in list is 4", firstidx { $_ == 4 } @list;
-    __END__
-    item with index 1 in list is 4
+=head3 apply BLOCK LIST
 
-Returns C<-1> if no such item could be found.
+Applies BLOCK to each item in LIST and returns a list of the values after BLOCK
+has been applied. In scalar context, the last element is returned. This
+function is similar to C<map> but will not modify the elements of the input
+list:
 
-C<first_index> is an alias for C<firstidx>.
+  my @list = (1 .. 4);
+  my @mult = apply { $_ *= 2 } @list;
+  print "\@list = @list\n";
+  print "\@mult = @mult\n";
+  __END__
+  @list = 1 2 3 4
+  @mult = 2 4 6 8
 
-=head2 lastidx BLOCK LIST
+Think of it as syntactic sugar for
 
-=head2 last_index BLOCK LIST
+  for (my @mult = @list) { $_ *= 2 }
 
-Returns the index of the last element in LIST for which the criterion in BLOCK
-is true. Sets C<$_> for each item in LIST in turn:
-
-    my @list = (1, 4, 3, 2, 4, 6);
-    printf "item with index %i in list is 4", lastidx { $_ == 4 } @list;
-    __END__
-    item with index 4 in list is 4
-
-Returns C<-1> if no such item could be found.
-
-C<last_index> is an alias for C<lastidx>.
-
-=head2 insert_after BLOCK VALUE LIST
+=head3 insert_after BLOCK VALUE LIST
 
 Inserts VALUE after the first item in LIST for which the criterion in BLOCK is
 true. Sets C<$_> for each item in LIST in turn.
 
-    my @list = qw/This is a list/;
-    insert_after { $_ eq "a" } "longer" => @list;
-    print "@list";
-    __END__
-    This is a longer list
+  my @list = qw/This is a list/;
+  insert_after { $_ eq "a" } "longer" => @list;
+  print "@list";
+  __END__
+  This is a longer list
 
-=head2 insert_after_string STRING VALUE LIST
+=head3 insert_after_string STRING VALUE LIST
 
 Inserts VALUE after the first item in LIST which is equal to STRING.
 
-    my @list = qw/This is a list/;
-    insert_after_string "a", "longer" => @list;
-    print "@list";
-    __END__
-    This is a longer list
+  my @list = qw/This is a list/;
+  insert_after_string "a", "longer" => @list;
+  print "@list";
+  __END__
+  This is a longer list
 
-=head2 apply BLOCK LIST
-
-Applies BLOCK to each item in LIST and returns a list of the values after BLOCK
-has been applied. In scalar context, the last element is returned.  This
-function is similar to C<map> but will not modify the elements of the input
-list:
-
-    my @list = (1 .. 4);
-    my @mult = apply { $_ *= 2 } @list;
-    print "\@list = @list\n";
-    print "\@mult = @mult\n";
-    __END__
-    @list = 1 2 3 4
-    @mult = 2 4 6 8
-
-Think of it as syntactic sugar for
-
-    for (my @mult = @list) { $_ *= 2 }
-
-=head2 before BLOCK LIST
-
-Returns a list of values of LIST up to (and not including) the point where BLOCK
-returns a true value. Sets C<$_> for each element in LIST in turn.
-
-=head2 before_incl BLOCK LIST
-
-Same as C<before> but also includes the element for which BLOCK is true.
-
-=head2 after BLOCK LIST
-
-Returns a list of the values of LIST after (and not including) the point
-where BLOCK returns a true value. Sets C<$_> for each element in LIST in turn.
-
-    @x = after { $_ % 5 == 0 } (1..9);    # returns 6, 7, 8, 9
-
-=head2 after_incl BLOCK LIST
-
-Same as C<after> but also includes the element for which BLOCK is true.
-
-=head2 indexes BLOCK LIST
-
-Evaluates BLOCK for each element in LIST (assigned to C<$_>) and returns a list
-of the indices of those elements for which BLOCK returned a true value. This is
-just like C<grep> only that it returns indices instead of values:
-
-    @x = indexes { $_ % 2 == 0 } (1..10);   # returns 1, 3, 5, 7, 9
-
-=head2 firstval BLOCK LIST
-
-=head2 first_value BLOCK LIST
-
-Returns the first element in LIST for which BLOCK evaluates to true. Each
-element of LIST is set to C<$_> in turn. Returns C<undef> if no such element
-has been found.
-
-C<first_val> is an alias for C<firstval>.
-
-=head2 lastval BLOCK LIST
-
-=head2 last_value BLOCK LIST
-
-Returns the last value in LIST for which BLOCK evaluates to true. Each element
-of LIST is set to C<$_> in turn. Returns C<undef> if no such element has been
-found.
-
-C<last_val> is an alias for C<lastval>.
-
-=head2 pairwise BLOCK ARRAY1 ARRAY2
+=head3 pairwise BLOCK ARRAY1 ARRAY2
 
 Evaluates BLOCK for each pair of elements in ARRAY1 and ARRAY2 and returns a
 new list consisting of BLOCK's return values. The two elements are set to C<$a>
-and C<$b>.  Note that those two are aliases to the original value so changing
+and C<$b>. Note that those two are aliases to the original value so changing
 them will modify the input arrays.
 
-    @a = (1 .. 5);
-    @b = (11 .. 15);
-    @x = pairwise { $a + $b } @a, @b;	# returns 12, 14, 16, 18, 20
+  @a = (1 .. 5);
+  @b = (11 .. 15);
+  @x = pairwise { $a + $b } @a, @b;     # returns 12, 14, 16, 18, 20
 
-    # mesh with pairwise
-    @a = qw/a b c/;
-    @b = qw/1 2 3/;
-    @x = pairwise { ($a, $b) } @a, @b;	# returns a, 1, b, 2, c, 3
+  # mesh with pairwise
+  @a = qw/a b c/;
+  @b = qw/1 2 3/;
+  @x = pairwise { ($a, $b) } @a, @b;    # returns a, 1, b, 2, c, 3
 
-=head2 each_array ARRAY1 ARRAY2 ...
+=head3 mesh ARRAY1 ARRAY2 [ ARRAY3 ... ]
 
-Creates an array iterator to return the elements of the list of arrays ARRAY1,
-ARRAY2 throughout ARRAYn in turn.  That is, the first time it is called, it
-returns the first element of each array.  The next time, it returns the second
-elements.  And so on, until all elements are exhausted.
-
-This is useful for looping over more than one array at once:
-
-    my $ea = each_array(@a, @b, @c);
-    while ( my ($a, $b, $c) = $ea->() )   { .... }
-
-The iterator returns the empty list when it reached the end of all arrays.
-
-If the iterator is passed an argument of 'C<index>', then it returns
-the index of the last fetched set of values, as a scalar.
-
-=head2 each_arrayref LIST
-
-Like each_array, but the arguments are references to arrays, not the
-plain arrays.
-
-=head2 natatime EXPR, LIST
-
-Creates an array iterator, for looping over an array in chunks of
-C<$n> items at a time.  (n at a time, get it?).  An example is
-probably a better explanation than I could give in words.
-
-Example:
-
-    my @x = ('a' .. 'g');
-    my $it = natatime 3, @x;
-    while (my @vals = $it->())
-    {
-        print "@vals\n";
-    }
-
-This prints
-
-    a b c
-    d e f
-    g
-
-=head2 mesh ARRAY1 ARRAY2 [ ARRAY3 ... ]
-
-=head2 zip ARRAY1 ARRAY2 [ ARRAY3 ... ]
+=head3 zip ARRAY1 ARRAY2 [ ARRAY3 ... ]
 
 Returns a list consisting of the first elements of each array, then
 the second, then the third, etc, until all arrays are exhausted.
 
 Examples:
 
-    @x = qw/a b c d/;
-    @y = qw/1 2 3 4/;
-    @z = mesh @x, @y;	    # returns a, 1, b, 2, c, 3, d, 4
+  @x = qw/a b c d/;
+  @y = qw/1 2 3 4/;
+  @z = mesh @x, @y;         # returns a, 1, b, 2, c, 3, d, 4
 
-    @a = ('x');
-    @b = ('1', '2');
-    @c = qw/zip zap zot/;
-    @d = mesh @a, @b, @c;   # x, 1, zip, undef, 2, zap, undef, undef, zot
+  @a = ('x');
+  @b = ('1', '2');
+  @c = qw/zip zap zot/;
+  @d = mesh @a, @b, @c;   # x, 1, zip, undef, 2, zap, undef, undef, zot
 
 C<zip> is an alias for C<mesh>.
 
-=head2 uniq LIST
+=head3 uniq LIST
 
-=head2 distinct LIST
+=head3 distinct LIST
 
-Returns a new list by stripping duplicate values in LIST. The order of
-elements in the returned list is the same as in LIST. In scalar context,
-returns the number of unique elements in LIST.
+Returns a new list by stripping duplicate values in LIST by comparing
+the values as hash keys, except that undef is considered separate from ''.
+The order of elements in the returned list is the same as in LIST. In
+scalar context, returns the number of unique elements in LIST.
 
-    my @x = uniq 1, 1, 2, 2, 3, 5, 3, 4; # returns 1 2 3 5 4
-    my $x = uniq 1, 1, 2, 2, 3, 5, 3, 4; # returns 5
+  my @x = uniq 1, 1, 2, 2, 3, 5, 3, 4; # returns 1 2 3 5 4
+  my $x = uniq 1, 1, 2, 2, 3, 5, 3, 4; # returns 5
+  # returns "Mike", "Michael", "Richard", "Rick"
+  my @n = distinct "Mike", "Michael", "Richard", "Rick", "Michael", "Rick"
+  # returns '', 'S1', A5' and complains about "Use of uninitialized value"
+  my @s = distinct '', undef, 'S1', 'A5'
+  # returns undef, 'S1', A5' and complains about "Use of uninitialized value"
+  my @w = uniq undef, '', 'S1', 'A5'
 
-=head2 minmax LIST
+C<distinct> is an alias for C<uniq>.
+
+B<RT#49800> can be used to give feedback about this behavior.
+
+=head3 singleton
+
+Returns a new list by stripping values in LIST occurring more than once by
+comparing the values as hash keys, except that undef is considered separate
+from ''. The order of elements in the returned list is the same as in LIST.
+In scalar context, returns the number of elements occurring only once in LIST.
+
+  my @x = singleton 1,1,2,2,3,4,5 # returns 3 4 5
+
+=head2 Partitioning
+
+=head3 after BLOCK LIST
+
+Returns a list of the values of LIST after (and not including) the point
+where BLOCK returns a true value. Sets C<$_> for each element in LIST in turn.
+
+  @x = after { $_ % 5 == 0 } (1..9);    # returns 6, 7, 8, 9
+
+=head3 after_incl BLOCK LIST
+
+Same as C<after> but also includes the element for which BLOCK is true.
+
+=head3 before BLOCK LIST
+
+Returns a list of values of LIST up to (and not including) the point where BLOCK
+returns a true value. Sets C<$_> for each element in LIST in turn.
+
+=head3 before_incl BLOCK LIST
+
+Same as C<before> but also includes the element for which BLOCK is true.
+
+=head3 part BLOCK LIST
+
+Partitions LIST based on the return value of BLOCK which denotes into which
+partition the current value is put.
+
+Returns a list of the partitions thusly created. Each partition created is a
+reference to an array.
+
+  my $i = 0;
+  my @part = part { $i++ % 2 } 1 .. 8;   # returns [1, 3, 5, 7], [2, 4, 6, 8]
+
+You can have a sparse list of partitions as well where non-set partitions will
+be undef:
+
+  my @part = part { 2 } 1 .. 10;            # returns undef, undef, [ 1 .. 10 ]
+
+Be careful with negative values, though:
+
+  my @part = part { -1 } 1 .. 10;
+  __END__
+  Modification of non-creatable array value attempted, subscript -1 ...
+
+Negative values are only ok when they refer to a partition previously created:
+
+  my @idx  = ( 0, 1, -1 );
+  my $i    = 0;
+  my @part = part { $idx[$++ % 3] } 1 .. 8; # [1, 4, 7], [2, 3, 5, 6, 8]
+
+=head2 Iteration
+
+=head3 each_array ARRAY1 ARRAY2 ...
+
+Creates an array iterator to return the elements of the list of arrays ARRAY1,
+ARRAY2 throughout ARRAYn in turn. That is, the first time it is called, it
+returns the first element of each array. The next time, it returns the second
+elements. And so on, until all elements are exhausted.
+
+This is useful for looping over more than one array at once:
+
+  my $ea = each_array(@a, @b, @c);
+  while ( my ($a, $b, $c) = $ea->() )   { .... }
+
+The iterator returns the empty list when it reached the end of all arrays.
+
+If the iterator is passed an argument of 'C<index>', then it returns
+the index of the last fetched set of values, as a scalar.
+
+=head3 each_arrayref LIST
+
+Like each_array, but the arguments are references to arrays, not the
+plain arrays.
+
+=head3 natatime EXPR, LIST
+
+Creates an array iterator, for looping over an array in chunks of
+C<$n> items at a time. (n at a time, get it?). An example is
+probably a better explanation than I could give in words.
+
+Example:
+
+  my @x = ('a' .. 'g');
+  my $it = natatime 3, @x;
+  while (my @vals = $it->())
+  {
+    print "@vals\n";
+  }
+
+This prints
+
+  a b c
+  d e f
+  g
+
+=head2 Searching
+
+=head3 bsearch BLOCK LIST
+
+Performs a binary search on LIST which must be a sorted list of values. BLOCK
+must return a negative value if the current element (stored in C<$_>) is smaller,
+a positive value if it is bigger and zero if it matches.
+
+Returns a boolean value in scalar context. In list context, it returns the element
+if it was found, otherwise the empty list.
+
+=head3 bsearchidx BLOCK LIST
+
+=head3 bsearch_index BLOCK LIST
+
+Performs a binary search on LIST which must be a sorted list of values. BLOCK
+must return a negative value if the current element (stored in C<$_>) is smaller,
+a positive value if it is bigger and zero if it matches.
+
+Returns the index of found element, otherwise C<-1>.
+
+C<bsearch_index> is an alias for C<bsearchidx>.
+
+=head3 firstval BLOCK LIST
+
+=head3 first_value BLOCK LIST
+
+Returns the first element in LIST for which BLOCK evaluates to true. Each
+element of LIST is set to C<$_> in turn. Returns C<undef> if no such element
+has been found.
+
+C<first_value> is an alias for C<firstval>.
+
+=head3 onlyval BLOCK LIST
+
+=head3 only_value BLOCK LIST
+
+Returns the only element in LIST for which BLOCK evaluates to true. Sets
+C<$_> for each item in LIST in turn. Returns C<undef> if no such element
+has been found.
+
+C<only_value> is an alias for C<onlyval>.
+
+=head3 lastval BLOCK LIST
+
+=head3 last_value BLOCK LIST
+
+Returns the last value in LIST for which BLOCK evaluates to true. Each element
+of LIST is set to C<$_> in turn. Returns C<undef> if no such element has been
+found.
+
+C<last_value> is an alias for C<lastval>.
+
+=head3 firstres BLOCK LIST
+
+=head3 first_result BLOCK LIST
+
+Returns the result of BLOCK for the first element in LIST for which BLOCK
+evaluates to true. Each element of LIST is set to C<$_> in turn. Returns
+C<undef> if no such element has been found.
+
+C<first_result> is an alias for C<firstres>.
+
+=head3 onlyres BLOCK LIST
+
+=head3 only_result BLOCK LIST
+
+Returns the result of BLOCK for the first element in LIST for which BLOCK
+evaluates to true. Sets C<$_> for each item in LIST in turn. Returns
+C<undef> if no such element has been found.
+
+C<only_result> is an alias for C<onlyres>.
+
+=head3 lastres BLOCK LIST
+
+=head3 last_result BLOCK LIST
+
+Returns the result of BLOCK for the last element in LIST for which BLOCK
+evaluates to true. Each element of LIST is set to C<$_> in turn. Returns
+C<undef> if no such element has been found.
+
+C<last_result> is an alias for C<lastres>.
+
+=head3 indexes BLOCK LIST
+
+Evaluates BLOCK for each element in LIST (assigned to C<$_>) and returns a list
+of the indices of those elements for which BLOCK returned a true value. This is
+just like C<grep> only that it returns indices instead of values:
+
+  @x = indexes { $_ % 2 == 0 } (1..10);   # returns 1, 3, 5, 7, 9
+
+=head3 firstidx BLOCK LIST
+
+=head3 first_index BLOCK LIST
+
+Returns the index of the first element in LIST for which the criterion in BLOCK
+is true. Sets C<$_> for each item in LIST in turn:
+
+  my @list = (1, 4, 3, 2, 4, 6);
+  printf "item with index %i in list is 4", firstidx { $_ == 4 } @list;
+  __END__
+  item with index 1 in list is 4
+
+Returns C<-1> if no such item could be found.
+
+C<first_index> is an alias for C<firstidx>.
+
+=head3 onlyidx BLOCK LIST
+
+=head3 only_index BLOCK LIST
+
+Returns the index of the only element in LIST for which the criterion
+in BLOCK is true. Sets C<$_> for each item in LIST in turn:
+
+    my @list = (1, 3, 4, 3, 2, 4);
+    printf "uniqe index of item 2 in list is %i", onlyidx { $_ == 2 } @list;
+    __END__
+    unique index of item 2 in list is 4
+
+Returns C<-1> if either no such item or more than one of these
+has been found.
+
+C<only_index> is an alias for C<onlyidx>.
+
+=head3 lastidx BLOCK LIST
+
+=head3 last_index BLOCK LIST
+
+Returns the index of the last element in LIST for which the criterion in BLOCK
+is true. Sets C<$_> for each item in LIST in turn:
+
+  my @list = (1, 4, 3, 2, 4, 6);
+  printf "item with index %i in list is 4", lastidx { $_ == 4 } @list;
+  __END__
+  item with index 4 in list is 4
+
+Returns C<-1> if no such item could be found.
+
+C<last_index> is an alias for C<lastidx>.
+
+=head2 Sorting
+
+=head3 sort_by BLOCK LIST
+
+Returns the list of values sorted according to the string values returned by the
+KEYFUNC block or function. A typical use of this may be to sort objects according
+to the string value of some accessor, such as
+
+  sort_by { $_->name } @people
+
+The key function is called in scalar context, being passed each value in turn as
+both $_ and the only argument in the parameters, @_. The values are then sorted
+according to string comparisons on the values returned.
+This is equivalent to
+
+  sort { $a->name cmp $b->name } @people
+
+except that it guarantees the name accessor will be executed only once per value.
+One interesting use-case is to sort strings which may have numbers embedded in them
+"naturally", rather than lexically.
+
+  sort_by { s/(\d+)/sprintf "%09d", $1/eg; $_ } @strings
+
+This sorts strings by generating sort keys which zero-pad the embedded numbers to
+some level (9 digits in this case), helping to ensure the lexical sort puts them
+in the correct order.
+
+=head3 nsort_by BLOCK LIST
+
+Similar to sort_by but compares its key values numerically.
+
+=head2 Counting and calculation
+
+=head3 true BLOCK LIST
+
+Counts the number of elements in LIST for which the criterion in BLOCK is true.
+Sets C<$_> for  each item in LIST in turn:
+
+  printf "%i item(s) are defined", true { defined($_) } @list;
+
+=head3 false BLOCK LIST
+
+Counts the number of elements in LIST for which the criterion in BLOCK is false.
+Sets C<$_> for each item in LIST in turn:
+
+  printf "%i item(s) are not defined", false { defined($_) } @list;
+
+=head3 minmax LIST
 
 Calculates the minimum and maximum of LIST and returns a two element list with
 the first element being the minimum and the second the maximum. Returns the
@@ -563,35 +816,6 @@ that there are more lines of Perl code involved. Therefore, LIST needs to be
 fairly big in order for C<minmax> to win over a naive implementation. This
 limitation does not apply to the XS version.
 
-=head2 part BLOCK LIST
-
-Partitions LIST based on the return value of BLOCK which denotes into which
-partition the current value is put.
-
-Returns a list of the partitions thusly created. Each partition created is a
-reference to an array.
-
-    my $i = 0;
-    my @part = part { $i++ % 2 } 1 .. 8;   # returns [1, 3, 5, 7], [2, 4, 6, 8]
-
-You can have a sparse list of partitions as well where non-set partitions will
-be undef:
-
-    my @part = part { 2 } 1 .. 10;	    # returns undef, undef, [ 1 .. 10 ]
-
-Be careful with negative values, though:
-
-    my @part = part { -1 } 1 .. 10;
-    __END__
-    Modification of non-creatable array value attempted, subscript -1 ...
-
-Negative values are only okay when they refer to a partition previously
-created:
-
-    my @idx  = ( 0, 1, -1 );
-    my $i    = 0;
-    my @part = part { $idx[$++ % 3] } 1 .. 8; # [1, 4, 7], [2, 3, 5, 6, 8]
-
 =head1 EXPORTS
 
 This module exports nothing by default. You can import functions by
@@ -599,7 +823,7 @@ name, or get everything with the C<:all> tag.
 
 =head1 SEE ALSO
 
-C<List::Util> and C<List::MoreUtils>, obviously.
+C<List::Util> and C<List::SomeUtils>, obviously.
 
 Also see C<Util::Any>, which unifies many more util modules, and also
 lets you rename functions as part of the import.
@@ -611,13 +835,41 @@ C<bug-list-allutils@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=List-AllUtils>
+(or L<bug-list-allutils@rt.cpan.org|mailto:bug-list-allutils@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module, please
+consider making a "donation" to me via PayPal. I spend a lot of free time
+creating free software, and would appreciate any support you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order for me
+to continue working on this particular software. I will continue to do so,
+inasmuch as I have in the past, for as long as it interests me.
+
+Similarly, a donation made in this way will probably not make me work on this
+software much more, unless I get so many donations that I can consider working
+on free software full time (let's all have a chuckle at that together).
+
+To donate, log into PayPal and send money to autarch@urth.org, or use the
+button at L<http://www.urth.org/~autarch/fs-donation.html>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 CONTRIBUTOR
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+=for stopwords Ricardo Signes
+
+Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
